==> cego-2.6.2.tar.gz: cego/src/CegoOrderSpace.h <==
#ifndef _CEGOORDERSPACE_H_INCLUDED_
#define _CEGOORDERSPACE_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoOrderSpace.h
// -----------------
// Order space class definition
//     
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2007 Bjoern Lemke
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoOrderSpace
// 
// Description: system space data elements
//
// Status: IMPLEMENTED
//
///////////////////////////////////////////////////////////////////////////////

#include "CegoDefs.h"
#include "Chain.h"
#include "CegoAttrDesc.h"
#include "CegoTableManager.h"
#include "CegoOrderCursor.h"
#include "CegoQueryHelper.h"

// forward declaration
class CegoTableManager;

class CegoOrderSpace {
    
 public:

    enum Ordering { ASC, DESC };

    CegoOrderSpace(CegoTableManager* pTM);
    ~CegoOrderSpace();
       
    void createOrderSpace(int tabSetId, const Chain& orderSpace, ListT<CegoExpr*> *pOrderList, ListT<Ordering> *pOrderOptList);
    void insertTuple(ListT<CegoField>& orderKey, ListT<CegoField>& orderTuple);
    void dropOrderSpace();

    CegoOrderCursor* getCursor();

 private:

    enum KeyComp { LOWER, EQUAL, HIGHER };

    KeyComp compKey(ListT<CegoField>& key1, ListT<CegoField>& key2);
    void insertTupleInTree(ListT<CegoField>& orderKey, ListT<CegoField>& orderTuple );
    void setAggregationValue(CegoExpr *pExpr, ListT<CegoField>& fl);

    CegoTableManager* _pTM;

    int _tabSetId;
    Chain _orderSpace;

    ListT<CegoExpr*>* _pOrderList;
    ListT<Ordering>* _pOrderOptList;
    ListT<CegoField> _orderSchema;

    CegoBufferPage _obp;
    CegoDataPointer _sysEntry;

    CegoDataPointer _rdp;
    CegoTableObject _oe;
    bool _isFirst;
    bool _isCreated;

    CegoQueryHelper _qh;
};

#endif

==> cego-2.6.8.tar.gz: cego/src/CegoOrderSpace.h <==
#ifndef _CEGOORDERSPACE_H_INCLUDED_
#define _CEGOORDERSPACE_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoOrderSpace.h
// -----------------
// Cego order space class definition
//     
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2010 Bjoern Lemke
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoOrderSpace
// 
// Description: Cego order space
//
// Status: QG-2.6
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include "Chain.h"

// cego includes
#include "CegoDefs.h"
#include "CegoAttrDesc.h"
#include "CegoTableManager.h"
#include "CegoOrderCursor.h"
#include "CegoQueryHelper.h"

// forward declaration
class CegoTableManager;

class CegoOrderSpace {
    
 public:

    enum Ordering { ASC, DESC };

    CegoOrderSpace(CegoTableManager* pTM);
    ~CegoOrderSpace();
       
    void createOrderSpace(int tabSetId, const Chain& orderSpace, ListT<CegoExpr*> *pOrderList, ListT<Ordering> *pOrderOptList);
    void insertTuple(ListT<CegoField>& orderKey, ListT<CegoField>& orderTuple);
    void dropOrderSpace();

    CegoOrderCursor* getCursor();

 private:

    enum KeyComp { LOWER, EQUAL, HIGHER };

    KeyComp compKey(ListT<CegoField>& key1, ListT<CegoField>& key2);
    void insertTupleInTree(ListT<CegoField>& orderKey, ListT<CegoField>& orderTuple );
    void setAggregationValue(CegoExpr *pExpr, ListT<CegoField>& fl);

    CegoTableManager* _pTM;

    int _tabSetId;
    Chain _orderSpace;

    ListT<CegoExpr*>* _pOrderList;
    ListT<Ordering>* _pOrderOptList;
    ListT<CegoField> _orderSchema;

    CegoBufferPage _obp;
    CegoDataPointer _sysEntry;

    CegoDataPointer _rdp;
    CegoTableObject _oe;
    bool _isFirst;
    bool _isCreated;

    CegoQueryHelper _qh;
};

#endif
